# -*- coding:utf-8 -*-
import pprint
from wencai.core.crawler import Wencai

global_execute_path = None
global_cn_col = False


def set_variable(execute_path=None, cn_col=False):
    global global_execute_path
    global_execute_path = execute_path
    global global_cn_col
    global_cn_col = cn_col
    return execute_path


def get_scrape_report(query, start_date, end_date, period, benchmark):
    return Wencai(execute_path=globals()['global_execute_path'], cn_col=globals()['global_cn_col']).backtest(
        query=query, start_date=start_date, end_date=end_date, period=period, benchmark=benchmark
    )


def get_strategy(query, start_date, end_date, stock_hold, upper_income, lower_income, period, fall_income,
                 day_buy_stock_num):
    return Wencai(execute_path=globals()['global_execute_path'], cn_col=globals()['global_cn_col']).yieldbacktest(
        query=query, start_date=start_date, end_date=end_date, period=period, fall_income=fall_income,
        day_buy_stock_num=day_buy_stock_num, upper_income=upper_income, lower_income=lower_income, stock_hold=stock_hold
    )


def get_event_evaluate(query, start_date, end_date, period, index_code):
    return Wencai(execute_path=globals()['global_execute_path'], cn_col=globals()['global_cn_col']).eventbacktest(
        query=query, start_date=start_date, end_date=end_date, period=period, index_code=index_code)



# -*- coding:utf-8 -*-
import os
import requests
from selenium import webdriver
from selenium.webdriver.chrome.options import Options


class Session(requests.Session):
    headers = {
        "Accept": "application/json,text/javascript,*/*;q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.8",
        'Connection': 'keep-alive',
        'Content-Length': "738",
        'Content-Type': "application/x-www-form-urlencoded; charset=UTF-8",
        'User-Agent': "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36",
        'X-Requested-With': "XMLHttpRequest"

    }

    def __init__(self, hexin_v=None, update_headers=None):
        requests.Session.__init__(self)
        self.headers.update(Session.headers)
        self.headers['hexin-v'] = hexin_v

        if update_headers is not None and isinstance(update_headers, dict):
            for k, v in update_headers.items():
                self.headers[k] = v

    def get_driver(self, url, execute_path=None, is_headless=True):
        driver = None
        try:
            chrome_options = Options()
            if is_headless:
                chrome_options.add_argument('--headless')
            chrome_options.add_argument('--disable-gpu')
            if execute_path is None:
                driver = webdriver.Chrome(chrome_options=chrome_options)
            else:
                driver = webdriver.Chrome(executable_path=execute_path, chrome_options=chrome_options)
            driver.get(url)
            return driver.page_source
        except Exception as e:
            raise IOError(e)
        finally:
            if driver is not None:
                driver.quit()



import wencai as wc





if __name__ == '__main__':
    wc.set_variable(cn_col=True, execute_path='/Users/allen/Downloads/chromedriver')

    # r = wc.get_backtest(query='上证指数上穿10日均线', start_date='2019-10-01', end_date='2019-10-19', period='1,2,3,4',
    #                     benchmark='hs000300')
    # print(r.history_detail(period='1'))

    # r = wc.get_yieldbacktest(query='非停牌；非st；今日振幅小于5%；量比小于1；涨跌幅大于-5%小于1%；流通市值小于20亿；市盈率大于25小于80；主力控盘比例从大到小',
    #                          start_date='2018-10-09', end_date='2019-07-16',
    #                          period='1',fall_income=1,lower_income=5,upper_income=9,day_buy_stock_num=1,
    #                          stock_hold=2
    #                          ).history_detail(period='3')

    r = wc.get_eventbacktest(end_date='2019-07-16',index_code="1a0001",period='1',query="上证指数上穿10日均线",
                         start_date="2016-05-16").report_data()
    print(r)






import os
import json
import time
from selenium import webdriver
from wencai.core.cons import WENCAI_LOGIN_URL
from selenium.webdriver.chrome.options import Options


class WencaiCookie:

    def __init__(self, execute_path=None, is_headless=True):
        self.execute_path = execute_path
        self.is_headless = is_headless

    def getHeXinVByHttp(self, source):
        driver = None
        try:
            chrome_options = Options()
            if self.is_headless:
                chrome_options.add_argument('--headless')
            chrome_options.add_argument('--disable-gpu')
            if self.execute_path is None:
                driver = webdriver.Chrome(chrome_options=chrome_options)
            else:
                driver = webdriver.Chrome(executable_path=self.execute_path, chrome_options=chrome_options)

            driver.get(WENCAI_LOGIN_URL[source])
            time.sleep(5)
            cookies = driver.get_cookies()
            v = ''
            for i in cookies:
                if 'name' in i.keys():
                    if i['name'] == 'v': v = i['value']
            return v
        except Exception as e:
            print(e)
        finally:
            driver.quit()

    def getHexinVByJson(self, source):
        json_path = os.path.dirname(__file__)+'/cookies.json'
        if os.path.exists(json_path):
            with open(json_path,'r') as f:
                cookies = json.load(f)
            if source in cookies:
                return cookies[source]
            else:
                henxin_v = self.getHeXinVByHttp(source=source)
                cookies[source] = henxin_v
                with open(json_path, 'w') as f:
                    json.dump(cookies, f)
                return henxin_v
        else:
            henxin_v = self.getHeXinVByHttp(source=source)
            cookies = dict()
            cookies[source] = henxin_v
            with open(json_path,'w') as f:
                json.dump(cookies,f)



import unittest
import wencai as wc


class TestWenCai(unittest.TestCase):

    def setUp(self) -> None:
        wc.set_variable(cn_col=True, execute_path='/Users/allen/Downloads/chromedriver')

    def test_get_scrape_report(self):
        r = wc.get_scrape_report(query='上证指数上穿10日均线',
                                 start_date='2019-10-01',
                                 end_date='2019-10-19',
                                 period='1,2,3,4',
                                 benchmark='hs000300')

        print(r.report_data)
        print(r.backtest_data)
        print(r.condition_data)
        print(r.history_detail(period='1'))

    def test_get_strategy(self):
        r = wc.get_strategy(query='非停牌；非st；今日振幅小于5%；量比小于1；涨跌幅大于-5%小于1%；流通市值小于20亿；市盈率大于25小于80；主力控盘比例从大到小',
                            start_date='2018-10-09',
                            end_date='2019-07-16',
                            period='1',
                            fall_income=1,
                            lower_income=5,
                            upper_income=9,
                            day_buy_stock_num=1,
                            stock_hold=2)
        print(r.profit_data)
        print(r.backtest_data)
        print(r.condition_data)
        print(r.history_detail(period='1'))
        print(r.history_pick(trade_date='2019-07-16', hold_num=1))

    def test_get_event_evaluate(self):
        r = wc.get_event_evaluate(end_date='2019-07-16',
                                  index_code="1a0001",
                                  period='1',
                                  query="上证指数上穿10日均线",
                                  start_date="2016-05-16")
        print(r.report_data)
        print(r.event_list)


if __name__ == '__main__':
    unittest.main()



# -*- coding:utf-8 -*-


WENCAI_LOGIN_URL = {
    "scrape_transaction": 'http://www.iwencai.com/traceback/strategy/transaction',
    "scrape_report": 'http://www.iwencai.com/traceback/strategy/submit',
    'strategy': 'http://www.iwencai.com/traceback/strategy/submit',
    "search": "http://www.iwencai.com/data-robot/extract-new",
    'recommend_strategy': 'http://www.iwencai.com/traceback/list/get-strategy',
    'backtest': 'http://backtest.10jqka.com.cn/backtest/app.html#/backtest'
}

WENCAI_CRAWLER_URL = {
    'history_detail': 'http://backtest.10jqka.com.cn/backtestonce/historydetail?\
                 sort_by=desc&id={backtest_id}&start_date={start_date}&end_date={end_date}&period={period}',
    "backtest": "http://backtest.10jqka.com.cn/backtestonce/backtest",
    "yieldbacktest": "http://backtest.10jqka.com.cn/tradebacktest/yieldbacktest",
    "history_pick": 'http://backtest.10jqka.com.cn/tradebacktest/historypick?\
                    query={query}&hold_num={hold_num}&trade_date={trade_date}',
    'eventbacktest':'http://backtest.10jqka.com.cn/eventbacktest/backtest',

}

WENCAI_HEADERS = {
    'backtest': {
        'Host': "backtest.10jqka.com.cn",
        'Origin': "http://backtest.10jqka.com.cn",
        "Referer": "http://backtest.10jqka.com.cn/backtest/app.html",
    }

}



# -*- coding:utf-8 -*-
import sys
import os
__author__ = 'allen yang'
__version__ = '0.1.1'
from wencai.core.event import (get_scrape_report,
                               set_variable,
                               get_strategy,
                               get_event_evaluate)


#!/usr/bin/env python
# coding=utf-8
import os
from setuptools import setup, find_packages

if os.path.exists("requirements.txt"):
    install_requires = open("requirements.txt").read().split("\n")
else:
    install_requires = []

setup(
    name='wencai',
    version='0.2.0',
    author='allen yang',
    author_email='allenyzx@163.com',
    url='https://upload.pypi.org/allenyzx/',
    description='this is a wencai crawler to get message',
    packages=find_packages(),
    install_requires=install_requires,
    license='MIT',
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.5",
    ],
    zip_safe=False,
    include_package_data=True,

)



# -*- coding:utf-8 -*-
import logging
import datetime as dt
from time import sleep
import pandas as pd
from wencai.core.cons import WENCAI_CRAWLER_URL, WENCAI_HEADERS
from wencai.core.content import BackTest, YieldBackTest, EventBackTest
from wencai.core.cookies import WencaiCookie
from wencai.core.session import Session

pd.set_option('display.width', 2000)


class Wencai(object):
    logging.basicConfig(
        level=logging.WARNING,
        format='%(asctime)s [%(levelname)s] %(message)s',
    )

    def __init__(self, execute_path=None, cn_col=False):
        self.execute_path = execute_path
        self.obj_cookie = WencaiCookie(execute_path=execute_path)
        self.cn_col = cn_col

    def backtest(self, query, start_date, end_date, period, benchmark):
        payload = {
            "query": query,
            "start_date": start_date,
            "end_date": end_date,
            "period": period,
            "benchmark": benchmark
        }
        henxin_v = self.obj_cookie.getHexinVByJson(source='backtest')
        session = Session(update_headers=WENCAI_HEADERS['backtest'], hexin_v=henxin_v)
        r = session.post(WENCAI_CRAWLER_URL['backtest'], data=payload)
        if r.status_code == 200:
            return BackTest(content=r.json(), cn_col=self.cn_col, execute_path=self.execute_path,
                            start_date=start_date, end_date=end_date)

        else:
            raise Exception(r.content.decode('utf-8'))

    def yieldbacktest(self, query, start_date, end_date, stock_hold, upper_income, lower_income, period, fall_income,
                      day_buy_stock_num):
        payload = {
            "query": query,
            "start_date": start_date,
            "end_date": end_date,
            "period": period,
            "stock_hold": stock_hold,
            "upper_income": upper_income,
            "lower_income": lower_income,
            "fall_income": fall_income,
            "day_buy_stock_num": day_buy_stock_num
        }
        henxin_v = self.obj_cookie.getHexinVByJson(source='backtest')
        session = Session(update_headers=WENCAI_HEADERS['backtest'], hexin_v=henxin_v)
        r = session.post(WENCAI_CRAWLER_URL['yieldbacktest'], data=payload)
        if r.status_code == 200:
            return YieldBackTest(content=r.json(), cn_col=self.cn_col, query=query, hexin_v=henxin_v,
                                 execute_path=self.execute_path,start_date=start_date,end_date=end_date)
        else:
            raise Exception(r.content.decode('utf-8'))

    def eventbacktest(self,query,index_code,period,start_date,end_date):
        payload = {
            "query": query,
            "start_date": start_date,
            "end_date": end_date,
            "period": period,
            "index_code":index_code
        }
        henxin_v = self.obj_cookie.getHexinVByJson(source='backtest')
        session = Session(update_headers=WENCAI_HEADERS['backtest'], hexin_v=henxin_v)
        r = session.post(WENCAI_CRAWLER_URL['eventbacktest'], data=payload)
        if r.status_code == 200:
            return EventBackTest(content=r.json(),cn_col=self.cn_col)
        else:
            raise Exception(r.content.decode('utf-8'))